# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`candlepin`](#candlepin): Manage a Candlepin server
* [`candlepin::repo`](#candlepinrepo): Manage the yum repository

#### Private Classes

* `candlepin::artemis`: Configuration for Artemis
* `candlepin::config`: Configuration for Candlepin
* `candlepin::database::mysql`: Candlepin Database Setup using Mysql
* `candlepin::database::postgresql`: Candlepin Database Setup using Postgresql
* `candlepin::install`: Candlepin installation packages
* `candlepin::params`: Candlepin params
* `candlepin::service`: Candlepin Service and Initialization

## Classes

### `candlepin`

Manage a Candlepin server

#### Parameters

The following parameters are available in the `candlepin` class.

##### `oauth_key`

Data type: `String`

The OAuth key for talking to the candlepin API

Default value: `$candlepin::params::oauth_key`

##### `oauth_secret`

Data type: `String`

The OAuth secret for talking to the candlepin API

Default value: `$candlepin::params::oauth_secret`

##### `manage_db`

Data type: `Boolean`

Whether a database should be installed, this includes db creation and user

Default value: `$candlepin::params::manage_db`

##### `init_db`

Data type: `Boolean`

Whether a database should be initialised.

Default value: `$candlepin::params::init_db`

##### `db_type`

Data type: `Enum['postgresql','mysql']`

The type of database Candlepin will be connecting too.

Default value: `$candlepin::params::db_type`

##### `db_host`

Data type: `String`

Hostname of database server.

Default value: `$candlepin::params::db_host`

##### `db_port`

Data type: `Optional[Integer[0, 65535]]`

Port the database listens on. Only needs to be provided if different from
standard port of the :db_type.

Default value: `$candlepin::params::db_port`

##### `db_ssl`

Data type: `Boolean`

Boolean indicating if the connection to the database should be over an SSL
connection.

Default value: `$candlepin::params::db_ssl`

##### `db_ssl_verify`

Data type: `Boolean`

Boolean indicating if the SSL connection to the database should be verified

Default value: `$candlepin::params::db_ssl_verify`

##### `db_name`

Data type: `String`

The name of the Candlepin database

Default value: `$candlepin::params::db_name`

##### `db_user`

Data type: `String`

The Candlepin database username

Default value: `$candlepin::params::db_user`

##### `db_password`

Data type: `String`

The Candlepin database password

Default value: `$candlepin::params::db_password`

##### `crl_file`

Data type: `Stdlib::Absolutepath`

The Certificate Revocation File for Candlepin

Default value: `$candlepin::params::crl_file`

##### `user_groups`

Data type: `Variant[Array[String], String]`

The user groups for the Candlepin tomcat user

Default value: `$candlepin::params::user_groups`

##### `log_dir`

Data type: `Stdlib::Absolutepath`

Directory for Candlepin logs

Default value: `$candlepin::params::log_dir`

##### `env_filtering_enabled`

Data type: `Boolean`

If subscription filtering is done on a per environment basis

Default value: `$candlepin::params::env_filtering_enabled`

##### `keystore_file`

Data type: `String`

Tomcat keystore file to use

Default value: `$candlepin::params::keystore_file`

##### `keystore_password`

Data type: `Optional[String]`

Password for keystore being used with Tomcat

Default value: `$candlepin::params::keystore_password`

##### `keystore_type`

Data type: `String`

Keystore type

Default value: `$candlepin::params::keystore_type`

##### `truststore_file`

Data type: `String`

Tomcat truststore file to use

Default value: `$candlepin::params::truststore_file`

##### `truststore_password`

Data type: `Optional[String]`

Password for truststore being used with Tomcat

Default value: `$candlepin::params::truststore_password`

##### `ca_key`

Data type: `Stdlib::Absolutepath`

CA key file to use

Default value: `$candlepin::params::ca_key`

##### `ca_cert`

Data type: `Stdlib::Absolutepath`

CA certificate file to use

Default value: `$candlepin::params::ca_cert`

##### `ca_key_password`

Data type: `Optional[String]`

CA key password

Default value: `$candlepin::params::ca_key_password`

##### `ciphers`

Data type: `Array[String]`

Allowed ciphers for ssl connection

Default value: `$candlepin::params::ciphers`

##### `tls_versions`

Data type: `Array[String]`

Allowed versions of TLS, for example 1.1, 1.2, etc

Default value: `$candlepin::params::tls_versions`

##### `version`

Data type: `String`

Version of Candlepin to install

Default value: `$candlepin::params::version`

##### `wget_version`

Data type: `String`

Version of wget to install

Default value: `$candlepin::params::wget_version`

##### `run_init`

Data type: `Boolean`

If the init api should be called on Candlepin

Default value: `$candlepin::params::run_init`

##### `adapter_module`

Data type: `Optional[String]`

Candlepin adapter implementations to inject into the java runtime

Default value: `$candlepin::params::adapter_module`

##### `enable_basic_auth`

Data type: `Boolean`

Whether to enable HTTP basic auth

Default value: `$candlepin::params::enable_basic_auth`

##### `enable_trusted_auth`

Data type: `Boolean`

Whether to enable trusted auth

Default value: `$candlepin::params::enable_trusted_auth`

##### `consumer_system_name_pattern`

Data type: `Optional[String]`

Regex that consistutes a valid consumer name

Default value: `$candlepin::params::consumer_system_name_pattern`

##### `enable_hbm2ddl_validate`

Data type: `Boolean`

If true will perform a schema check to ensure compliance with the models.
Disabling this feature may be required if modifications are required to schema

Default value: `$candlepin::params::enable_hbm2ddl_validate`

##### `ssl_port`

Data type: `Integer[0, 65535]`

Port to deploy SSL enabled Tomcat server on

Default value: `$candlepin::params::ssl_port`

##### `host`

Data type: `Stdlib::Host`

Host to deploy Tomcat server on; defaults to localhost

Default value: `$candlepin::params::host`

##### `candlepin_conf_file`

Data type: `Stdlib::Absolutepath`

Configuration file location for candlepin

Default value: `$candlepin::params::candlepin_conf_file`

##### `tomcat_base`

Data type: `Stdlib::Absolutepath`

In new-style instances, if CATALINA_BASE isn't specified, it will be
constructed by joining TOMCATS_BASE and NAME.

Default value: `$candlepin::params::tomcat_base`

##### `java_home`

Data type: `Stdlib::Absolutepath`

Where your java installation lives

Default value: `$candlepin::params::java_home`

##### `catalina_home`

Data type: `Stdlib::Absolutepath`

Where your tomcat installation lives

Default value: `$candlepin::params::catalina_home`

##### `catalina_tmpdir`

Data type: `Stdlib::Absolutepath`

System-wide tmp

Default value: `$candlepin::params::catalina_tmpdir`

##### `java_opts`

Data type: `String`

Java Parameters

Default value: `$candlepin::params::java_opts`

##### `lang`

Data type: `Optional[String]`

Tomcat locale setting

Default value: `$candlepin::params::lang`

##### `security_manager`

Data type: `Boolean`

Run tomcat under the Java Security Manager

Default value: `$candlepin::params::security_manager`

##### `shutdown_wait`

Data type: `Optional[Integer[0]]`

Time to wait in seconds, before killing process

Default value: `$candlepin::params::shutdown_wait`

##### `expired_pools_schedule`

Data type: `String`

Quartz schedule notation for how often to run the ExpiredPoolsJob

Default value: `$candlepin::params::expired_pools_schedule`

##### `certificate_revocation_list_task_schedule`

Quartz schedule notation for how often to run CRL generation

##### `artemis_port`

Data type: `Stdlib::Port`

Port to expose Artemis on

Default value: `$candlepin::params::artemis_port`

##### `artemis_host`

Data type: `Stdlib::Host`

Host address to have Artemis listen on; defaults to localhost

Default value: `$candlepin::params::host`

##### `artemis_client_dn`

Data type: `String`

Full DN for the client certificate used to talk to Artemis

Default value: `$candlepin::params::artemis_client_dn`

### `candlepin::repo`

Manage the yum repository

#### Parameters

The following parameters are available in the `candlepin::repo` class.

##### `version`

Data type: `String`

Which yum repository to install. For example latest or 3.3. Note that the
versions are Katello releases.

##### `dist`

Data type: `String`

The dist code to use in the URL

Default value: `"el${facts['os']['release']['major']}"`

##### `gpgcheck`

Data type: `Boolean`

Whether to check the GPG signatures

Default value: ``false``

##### `gpgkey`

Data type: `Optional[String]`

The GPG key to use

Default value: ``undef``

